@@ -111,8 +111,9 @@ class ImageDrawEx(object):
             self.image = Image.new('RGB', size, (256, 256, 256))
 
             # set transparency to background
-            alpha = Image.new('L', size, 1)
-            self.image.putalpha(alpha)
+            if kwargs.get('transparency'):
+                alpha = Image.new('L', size, 1)
+                self.image.putalpha(alpha)
 
         self.filename = filename
         self.scale_ratio = kwargs.get('scale_ratio', 1)
@@ -298,7 +299,8 @@ class ImageDrawEx(object):
             else:
                 _box = box
 
-            text = ImageDrawEx(None, _box.size, parent=self, mode=self.mode)
+            text = ImageDrawEx(None, _box.size, parent=self, mode=self.mode,
+                               transparency=True)
             textbox = (0, 0, _box.width, _box.height)
             text.textarea(textbox, string, font, **kwargs)
 
@@ -313,8 +315,14 @@ class ImageDrawEx(object):
             outline = kwargs.get('outline')
             self.rectangle(lines.outlinebox, fill='white', outline=outline)
 
+        rendered = False
         for string, xy in lines.lines:
             self.text(xy, string, font, **kwargs)
+            rendered = True
+
+        if not rendered and font.size > 0:
+            font.size = int(font.size * 0.8)
+            self.textarea(box, string, font, **kwargs)
 
     def loadImage(self, filename, box):
         box_width = box[2] - box[0]
