@@ -49,14 +49,14 @@ class Application(object):
         self.fontmap = create_fontmap(self.options)
 
     def parse_diagram(self):
+        import codecs
         if self.options.input == '-':
-            import codecs
             stream = codecs.getreader('utf-8')(sys.stdin)
-            tree = self.module.parser.parse_string(stream.read())
+            self.code = stream.read()
         else:
-            tree = self.module.parser.parse_file(self.options.input)
+            self.code = codecs.open(self.options.input, 'r', 'utf-8').read()
 
-        return tree
+        return self.module.parser.parse_string(self.code)
 
     def build_diagram(self, tree):
         DiagramDraw = self.module.drawer.DiagramDraw
@@ -65,7 +65,7 @@ class Application(object):
 
         drawer = DiagramDraw(self.options.type, diagram,
                              self.options.output, fontmap=self.fontmap,
-                             antialias=self.options.antialias,
+                             code=self.code, antialias=self.options.antialias,
                              nodoctype=self.options.nodoctype,
                              transparency=self.options.transparency)
         drawer.draw()
@@ -122,8 +122,9 @@ class Options(object):
         elif self.options.output == '-':
             self.options.output = 'output.' + self.options.type.lower()
         else:
+            basename = os.path.splitext(self.options.input)[0]
             ext = '.%s' % self.options.type.lower()
-            self.options.output = re.sub('\..*?$', ext, self.options.input)
+            self.options.output = basename + ext
 
         self.options.type = self.options.type.upper()
         if not self.options.type in ('SVG', 'PNG', 'PDF'):
@@ -181,13 +182,23 @@ class Options(object):
 
 
 def detectfont(options):
-    fonts = ['c:/windows/fonts/VL-Gothic-Regular.ttf',  # for Windows
-             'c:/windows/fonts/msgothic.ttf',  # for Windows
-             'c:/windows/fonts/msgoth04.ttc',  # for Windows
-             '/usr/share/fonts/truetype/ipafont/ipagp.ttf',  # for Debian
-             '/usr/local/share/font-ipa/ipagp.otf',  # for FreeBSD
-             '/Library/Fonts/Hiragino Sans GB W3.otf',  # for MacOS
-             '/System/Library/Fonts/AppleGothic.ttf']  # for MacOS
+    fonts = [
+        # for Windows
+        'c:/windows/fonts/VL-Gothic-Regular.ttf',
+        'c:/windows/fonts/msgothic.ttf',
+        'c:/windows/fonts/msgoth04.ttc',
+        # for Debian (squeeze)
+        '/usr/share/fonts/truetype/ipafont/ipagp.ttf',
+        '/usr/share/fonts/truetype/vlgothic/VL-PGothic-Regular.ttf',
+        # for Debian (wheezy)
+        '/usr/share/fonts/opentype/ipafont-gothic/ipagp.ttf',
+        '/usr/share/fonts/truetype/vlgothic/VL-PGothic-Regular.ttf',
+        # for MacOS
+        '/Library/Fonts/Hiragino Sans GB W3.otf',  # for MacOS
+        '/System/Library/Fonts/AppleGothic.ttf',  # for MacOS
+        # for FreeBSD
+        '/usr/local/share/font-ipa/ipagp.otf',  # for FreeBSD
+    ]
 
     fontpath = None
     if options.font:
